<?php
/*
Plugin Name: Mein Autor Box Plugin
Plugin URI: https://wpwissen.com/wordpress-plugin-erstellen
Description: Dieses Plugin zeigt unter den einzelnen Artikeln eine Autor Box an. Es dient zur Demonstration für den Artikel "Ein WordPress Plugin erstellen - so geht's", erschienen auf wpwissen.com.
Author: Peter von wpwissen.com
Author URI: https://wpwissen.com
Version: 1.0.0
*/


// Direkten Aufruf verhindern
if ( ! defined( 'WPINC' ) ) {
  
	die;
  
}


// Funktion zum Anzeigen einer Autor Box am Ende eines einzelnen Artikels
// Der Parameter $content enthält den gesamten Inhalt des Artikels
// An diesen hängen wir unsere Autor Box am Ende an
function mp_autor_box( $content ) {

  // Die Autor Box soll nur dann angezeigt werden, wenn aktuell ein einzelner Artikel angezeigt wird
  // Die Autor Box wird also weder in einer Übersicht mit mehreren Artikeln angezeigt (Blog Index, Archive, Suchergebnis),
  // noch auf einer Seite
  if ( is_single() ) {
 
    // Name des Autors
    $mp_autor_name = get_the_author_meta( 'display_name' );
    
    // Website des Autors
    $mp_autor_website = get_the_author_meta( 'url' );
 
    // Biografische Angaben des Autors
    $mp_autor_bio = get_the_author_meta( 'user_description' );
 
    // Link zur Autoren-Seite (auf dieser werden standardmäßig alle Beiträge eines Autors aufgelistet)
    $mp_autor_archiv = get_author_posts_url( get_the_author_meta( 'ID' ) );
    
    // Das Profilbild von gravatar.com abrufen
    $mp_autor_avatar = get_avatar( get_the_author_meta( 'user_email' ) );
    
    
    // Wenn ein Gravatar vorhanden ist, den HTML-Code für die Darstellung des Gravatars erzeugen
    if ( ! empty( $mp_autor_avatar ) ) {
      
      $mp_autor_avatar_html = '<div class="mp-autor-avatar">';
      
      // Wenn eine Website eingetragen ist, verlinken wir den Gravatar mit der Website
      if ( ! empty( $mp_autor_website ) ) {
        
        $mp_autor_avatar_html .= '<a href="' . $mp_autor_website . '">';
        
      }
      
      $mp_autor_avatar_html .= $mp_autor_avatar;
      
      // Wenn eine Website eingetragen ist, den <a> Tag schließen
      if ( ! empty( $mp_autor_website ) ) {
        
        $mp_autor_avatar_html .= '</a>';
        
      }
      
      $mp_autor_avatar_html .= '</div>';
      
    }
    
    
    // Wenn eine Biografie vorhanden ist, HTML-Code erzeugen
    if ( ! empty( $mp_autor_bio ) ) {
      
      $mp_autor_bio_html = '<div class="mp-autor-bio"> ' . $mp_autor_bio . '</div>';
      
    }
    
    
    // HTML-COde für den Link zur Autoren-Seite erzeugen
    $mp_autor_links_html = '<a href=' . $mp_autor_archiv . '">Alle Artikel von ' . $mp_autor_name . '</a>';
    
    
    
    // Wenn eine Website eingetragen ist, Link hinzufügen
    if ( ! empty( $mp_autor_website ) ) {
      
      $mp_autor_links_html .= ' | <a href="' . $mp_autor_website . '">Website von ' . $mp_autor_name . '</a>';
      
    }
    
    
    // Die Autor Box zusammensetzen
    $mp_autor_box = '
      <footer class="pm-autor-box" >
        <p class="pm-autor-titel">Über den Autor</p>
        <div class="pm-autor-name">' . $mp_autor_avatar_html . $mp_autor_name . '</div>' .
        $mp_autor_bio_html .
        '<div class="pm-autor-links">' . $mp_autor_links_html . '</div>
      </footer>';
      
      
    // Die Autor Box an das Ende des Inhalts anfügen 
    $content .= $mp_autor_box;
    
  }
  
  // Den Inhalt zurückliefern
  // Entweder ergänzt um die Autor Box oder sonst den originalen Inhalt
  return $content;
  
}


// Funktion zum Laden der CSS Datei
function mp_css() {
  
  wp_enqueue_style( 'mein-plugin-style', plugin_dir_url( __FILE__ ) . 'mein-plugin.css' );
  
}
 

// Die Funktion mp_autor_box() zum Filter the_content hinzufügen
add_filter( 'the_content', 'mp_autor_box' );


// Die Funtion mp_css() zur Action wp_enqueue_scripts hinzufügen
// Dieser Action-Hook wird zum Ladsen sowohl für JavaScript- als auch für CSS-Dateien verwendet
// ES gibt keinen eigenen Hook für CSS
add_action( 'wp_enqueue_scripts', 'mp_css' );

?>